==> cms-db_v0.8.1.tar.gz: admin/locales/de/locale_frame.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['frame'] = array();

$locale['frame']['admin_logout'] = 'Möchten Sie den Verwaltungsbereich von cms -db wirklich verlassen?<br />Alle geöffneten Unterfenster werden geschlossen und der komplette Inhalt des Recycling-Centers wird unwiderruflich gelöscht!';
$locale['frame']['button_menu'] = 'Menü';
$locale['frame']['button_update'] = 'Aktualisierung verfügbar';
$locale['frame']['button_preview'] = 'Website anzeigen';
$locale['frame']['button_about'] = 'Über cms -db';
$locale['frame']['button_desktop'] = 'Alle Unterfenster ausblenden';
$locale['frame']['button_logout'] = 'Verwaltungsbereich verlassen';
$locale['frame']['desc_no-js'] = 'Ihr Browser unterstützt kein Javascript oder es ist deaktiviert.';
$locale['frame']['link_no-js'] = 'Klicken Sie hier für eine alternative Version von cms -db ohne Javascript.';
$locale['frame']['desc_ie-friendly'] = 'cms -db wird von Ihrem Browser unterstützt, aber es könnte kleinere Probleme geben oder einige Funktionen könnten defekt sein.';
$locale['frame']['desc_ie'] = 'Ihr Browser unterstützt cms -db nicht vollständig. Sie haben nun folgende Möglichkeiten:';
$locale['frame']['link_better-browser'] = 'Verwenden Sie einen besseren Browser (empfohlen für den vollen Funktionsumfang)';
$locale['frame']['link_newer-ie'] = 'Aktualisieren Sie Ihren Browser mit Windows Update (empfohlen)';
$locale['frame']['link_quirksmode'] = 'Verwenden Sie die Kompatibilitätsversion';
$locale['frame']['link_fullversion'] = 'Verwenden Sie die Vollversion mit Einschränkungen';
$locale['frame']['desc_update-available'] = 'Eine Aktualisierung auf Version %s ist verfügbar. Wenn Sie diese installieren möchten, laden Sie das Paket herunter und melden Sie sich ab. Nachdem die Dateien auf den Server kopiert wurden, muss die Aktualisierung durch Anmelden als Hauptbenutzer vervollständigt werden.';
$locale['frame']['desc_update-available-auto'] = 'Eine Aktualisierung auf Version %s ist verfügbar. Sie wird automatisch heruntergeladen und installiert.';
$locale['frame']['button_download'] = 'Herunterladen';
$locale['frame']['button_more-info'] = 'Mehr Informationen';

$locale['frame']['desc_compatversion'] = 'Kompatibilitätsversion';
?>

==> cms-db_v0.9.tar.gz: admin/locales/de/locale_frame.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    For a full list of authors, see info.php
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

$locale['frame'] = array();

$locale['frame']['admin_logout'] = 'Möchten Sie den Verwaltungsbereich von cms -db wirklich verlassen?<br />Alle geöffneten Unterfenster werden geschlossen und der komplette Inhalt des Recycling-Centers wird unwiderruflich gelöscht!';
$locale['frame']['button_menu'] = 'Menü';
$locale['frame']['button_update'] = 'Aktualisierung verfügbar';
$locale['frame']['button_update-none'] = 'Auf dem aktuellen Stand';
$locale['frame']['button_update-manual'] = 'Aktualisierungsverwaltung';
$locale['frame']['button_preview'] = 'Website anzeigen';
$locale['frame']['button_about'] = 'Über cms -db';
$locale['frame']['button_desktop'] = 'Alle Unterfenster ausblenden';
$locale['frame']['button_logout'] = 'Verwaltungsbereich verlassen';
$locale['frame']['desc_no-js'] = 'Ihr Browser unterstützt kein Javascript oder es ist deaktiviert.';
$locale['frame']['link_no-js'] = 'Klicken Sie hier für eine alternative Version von cms -db ohne Javascript.';
$locale['frame']['desc_ie-friendly'] = 'cms -db wird von Ihrem Browser unterstützt, aber es könnte kleinere Probleme geben oder einige Funktionen könnten defekt sein.';
$locale['frame']['desc_ie'] = 'Ihr Browser unterstützt cms -db nicht vollständig. Sie haben nun folgende Möglichkeiten:';
$locale['frame']['link_better-browser'] = 'Verwenden Sie einen besseren Browser (empfohlen für den vollen Funktionsumfang)';
$locale['frame']['link_newer-ie'] = 'Aktualisieren Sie Ihren Browser mit Windows Update (empfohlen)';
$locale['frame']['link_quirksmode'] = 'Verwenden Sie die Kompatibilitätsversion';
$locale['frame']['link_fullversion'] = 'Verwenden Sie die Vollversion mit Einschränkungen';
$locale['frame']['desc_compatversion'] = 'Kompatibilitätsversion';
